<?php
declare(strict_types=1);

namespace FiloBlu\Csp\Model;

use FiloBlu\Csp\Api\CspRendererInterface;
use FiloBlu\Csp\Api\ConfigManagerInterface;
use Magento\Framework\App\Area;
use Magento\Framework\App\Response\HttpInterface as HttpResponse;
use Magento\Framework\App\State;

/**
 * @inheritDoc
 */
class CspRenderer implements CspRendererInterface
{

    protected $configManager;

    protected $policies;

    /**
     * @param State $state
     */
    public function __construct(ConfigManagerInterface $configManager, $policies = array())
    {
        $this->configManager = $configManager;
        $this->policies = $policies;
    }

    /**
     * @inheritDoc
     */
    public function render(HttpResponse $response)
    {
        $config = $this->configManager->getConfiguration();

        if ($config->isCspEnabled() == false) {
            return;
        }

        foreach ($this->policies as $policyConfigPath => $policy) {
            $policyValue = $this->configManager->getPolicyValue($policyConfigPath);
            if ($policyValue == null || trim($policyValue) == '') {
                continue;
            }

            if ($config->isReportOnly()) {
                $header = 'Content-Security-Policy-Report-Only';
            } else {
                $header = 'Content-Security-Policy';
            }
            $value = $policy . ' ' . $policyValue . ';';
            if ($config->getReportUri() && !$response->getHeader('Report-To')) {
                $reportToData = [
                    'group' => 'report-endpoint',
                    'max_age' => 10886400,
                    'endpoints' => [
                        ['url' => $config->getReportUri()]
                    ]
                ];
                $value .= ' report-uri ' . $config->getReportUri() . ';';
                $value .= ' report-to ' . $reportToData['group'] . ';';
                $response->setHeader('Report-To', json_encode($reportToData), true);
            }
            if ($existing = $response->getHeader($header)) {
                $value = $value . ' ' . $existing->getFieldValue();
            }
            $response->setHeader($header, $value, true);

        }

    }
}
