<?php
declare(strict_types=1);

namespace FiloBlu\Csp\Observer;

use FiloBlu\Csp\Api\CspRendererInterface;
use Magento\Framework\App\Area;
use Magento\Framework\App\State;
use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\App\Response\HttpInterface as HttpResponse;

class FrontSendResponseBefore implements \Magento\Framework\Event\ObserverInterface
{

    /**
     * @var CspRendererInterface
     */
    private $cspRenderer;

    /**
     * @var State
     */
    private $state;

    /**
     * @param CspRendererInterface $cspRenderer
     */
    public function __construct(CspRendererInterface $cspRenderer, State $state)
    {
        $this->cspRenderer = $cspRenderer;
        $this->state = $state;
    }

    /**
     * Execute observer
     *
     * @param \Magento\Framework\Event\Observer $observer
     * @return void
     */
    public function execute(
        \Magento\Framework\Event\Observer $observer
    ) {
        
        try {
            $area = $this->state->getAreaCode();
        } catch (\Exception $e) {
            $area = null;
        }
        if (!in_array($area, [Area::AREA_ADMINHTML, Area::AREA_FRONTEND])) {
            return;
        }
        
        /** @var HttpResponse $response */
        $response = $observer->getEvent()->getData('response');

        $this->cspRenderer->render($response);
    }
}
